@@ -2,6 +2,7 @@ import copy
 import logging
 import re
 import typing
+import warnings
 from contextlib import suppress
 from inspect import getdoc, iscoroutinefunction
 
@@ -303,7 +304,7 @@ class SlashCommand:
                             }
                             if y in selected.permissions:
                                 command_dict["permissions"][y] = selected.permissions[y]
-                            wait[y][x] = copy.deepcopy(command_dict)
+                            wait[y][_x] = copy.deepcopy(command_dict)
                     else:
                         if "global" not in wait:
                             wait["global"] = {}
@@ -314,7 +315,7 @@ class SlashCommand:
                             "permissions": selected.permissions or {},
                             "type": selected._type,
                         }
-                        wait["global"][x] = copy.deepcopy(command_dict)
+                        wait["global"][_x] = copy.deepcopy(command_dict)
 
                 continue
 
@@ -735,8 +736,8 @@ class SlashCommand:
         :type description: str
         :param base_description: Description of the base command. Default ``None``.
         :type base_description: str
-        :param default_permission: Sets if users have permission to run base command by default, when no permissions are set. Default ``True``.
-        :type default_permission: bool
+        :param base_default_permission: Sets if users have permission to run base command by default, when no permissions are set. Default ``True``.
+        :type base_default_permission: bool
         :param base_permissions: Dictionary of permissions of the slash command. Key being target guild_id and value being a list of permissions to apply. Default ``None``.
         :type base_permissions: dict
         :param subcommand_group_description: Description of the subcommand_group. Default ``None``.
@@ -966,8 +967,8 @@ class SlashCommand:
         :param base_description: Description of the base command. Default ``None``.
         :type base_description: str
         :param base_desc: Alias of ``base_description``.
-        :param default_permission: Sets if users have permission to run slash command by default, when no permissions are set. Default ``True``.
-        :type default_permission: bool
+        :param base_default_permission: Sets if users have permission to run slash command by default, when no permissions are set. Default ``True``.
+        :type base_default_permission: bool
         :param permissions: Permission requirements of the slash command. Default ``None``.
         :type permissions: dict
         :param subcommand_group_description: Description of the subcommand_group. Default ``None``.
@@ -1395,6 +1396,13 @@ class SlashCommand:
         to_use = msg["d"]
         interaction_type = to_use["type"]
 
+        # it's time to start using the new module guys,
+        # sorry.
+        warnings.warn(
+            message='This pip module is now deprecated as of version 3.0.1a! Please use the new module "discord-py-interactions" to gain access to 3.0.2 and future versions.',
+            category=DeprecationWarning,
+        )
+
         # dis_snek variance seq
 
         if interaction_type in (1, 2):
