@@ -447,7 +447,7 @@ class CogComponentCallbackObject(ComponentCallbackObject):
 
 class SlashCommandOptionType(IntEnum):
     """
-    Equivalent of `ApplicationCommandOptionType <https://discord.com/developers/docs/interactions/slash-commands#applicationcommandoptiontype>`_  in the Discord API.
+    Equivalent of `ApplicationCommandOptionType <https://discord.com/developers/docs/interactions/application-commands#application-command-object-application-command-option-type>`_  in the Discord API.
     """
 
     SUB_COMMAND = 1
@@ -667,7 +667,7 @@ class GuildPermissionsData:
 
 class SlashCommandPermissionType(IntEnum):
     """
-    Equivalent of `ApplicationCommandPermissionType <https://discord.com/developers/docs/interactions/slash-commands#applicationcommandpermissiontype>`_  in the Discord API.
+    Equivalent of `ApplicationCommandPermissionType <https://discord.com/developers/docs/interactions/application-commands#application-command-permissions-object-application-command-permission-type>`_  in the Discord API.
     """
 
     ROLE = 1
